/*******************************************************************************
*
*	Filename		:	SimpleExample.c
*	Description		:	Simple C application demosntrating how to
*						open, grab an image and close the FingerChip
*						Example part of the SDK
*
*	Company			:	ATMEL-Grenoble
*	Project			:	FingerChip
*	Authors			:	AC	Alain Chambron
*
*	Platform		:	independant
*	Language		:	C ANSI
*	Operating System:	independant
*
*	History
*	28-JUL-2003 AC	:	created
*
*	Copyright (c)2001-2003  All rights reserved
******************************************************************************/

#include <stdio.h>
#include "FCGetImage.h"

#define IMAGE_X 280
#define IMAGE_Y 320

void write_bmp( FILE *stream, unsigned char *buffer, unsigned short x_img, unsigned short y_img )
{
	unsigned int	val ;
	int				i ;
		
	fprintf( stream, "%c%c", 0x42, 0x4D ) ;
	val = 14+40+4*256+x_img*y_img ;fwrite(&val,4,1,stream);
	val = 0x0000;fwrite(&val,4,1,stream);
	val = 14+40+4*256;fwrite(&val,4,1,stream);
	val = 0x0028;fwrite(&val,4,1,stream);
	val = x_img;fwrite(&val,4,1,stream);
	val = y_img;fwrite(&val,4,1,stream);
	val = 0x01;fwrite(&val,2,1,stream);
	val = 0x08;fwrite(&val,2,1,stream);
	val = 0x0000;fwrite(&val,4,1,stream);
	val = 0x0000;fwrite(&val,4,1,stream);
	val = 0x0000;fwrite(&val,4,1,stream);
	val = 0x0000;fwrite(&val,4,1,stream);
	val = 0x0000;fwrite(&val,4,1,stream);
	val = 0x0000;fwrite(&val,4,1,stream);
		
	for( i=0; i<256; i++ )
	{
		val = i;
		fwrite(&val,1,1,stream);
		fwrite(&val,1,1,stream);
		fwrite(&val,1,1,stream);
		val = 0;fwrite(&val,1,1,stream);
	}
	
	for( i=y_img-1; i>=0; i-- )
	{
		fwrite( buffer + i*x_img, x_img, 1, stream ) ;
	}
}

int main( int argc, char *argv[] )
{
	short			errCode ;
	unsigned char	ImageBuffer[IMAGE_X*IMAGE_Y] ;
	t_FC_ImageInfo	imageInfo ;
	FILE			*pBmpFile ;

	// first open the fingerchip device
	errCode = FC_OpenDevice() ;

	if( FC_OK != errCode )
	{
		fprintf( stderr, "Failed opening FingerChip - Errno 0x%x\n", errCode ) ;
		return 0 ;
	}
	else
		fprintf( stdout, "Succeded opening FingerChip\n" ) ;

	fprintf( stdout, "Please sweep your finger...\n") ;

	// then grab an image
	errCode = FC_GetImage( ImageBuffer, IMAGE_X, IMAGE_Y, &imageInfo ) ;
	//errCode = FC_GetSlice( ImageBuffer, 17920, 0 ) ;

	if( FC_OK != errCode )
		fprintf( stderr, "Failed grabbing image - Errno 0x%x\n", errCode ) ;
	else
		fprintf( stdout, "Succeded grabbing image\n" ) ;

	// the image is saved to a temporary bitmap file
	
	pBmpFile = fopen( "./out.bmp", "wb" ) ;

	if( pBmpFile )
	{
		write_bmp( pBmpFile, ImageBuffer, IMAGE_X, IMAGE_Y ) ;
		//write_bmp( pBmpFile, ImageBuffer, 280, 64 ) ;
		fclose( pBmpFile ) ;
	}

	// close the FingerChip device
	errCode = FC_CloseDevice() ;

	if( FC_OK != errCode )
		fprintf( stderr, "Failed closing FingerChip - Errno 0x%x\n", errCode ) ;
	
	return 0 ;
}
